Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3930)

Unified Diff: chrome/browser/ui/cocoa/dev_tools_controller.h

Issue 9265018: Change grow box computation back to a method on BrowserWindow (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: nits Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/dev_tools_controller.h
diff --git a/chrome/browser/ui/cocoa/dev_tools_controller.h b/chrome/browser/ui/cocoa/dev_tools_controller.h
index f4fa57f99b0374e66b460d01bec6e482a2f12c37..09c2ac602b88f1172724556ff5f6f33bca46e049 100644
--- a/chrome/browser/ui/cocoa/dev_tools_controller.h
+++ b/chrome/browser/ui/cocoa/dev_tools_controller.h
@@ -10,16 +10,18 @@
#import "base/mac/cocoa_protocols.h"
#include "base/memory/scoped_nsobject.h"
-#import "chrome/browser/ui/cocoa/tab_contents/tab_contents_controller.h"
@class NSSplitView;
@class NSView;
class Profile;
-class TabContents;
+
+namespace content {
+class WebContents;
+}
// A class that handles updates of the devTools view within a browser window.
// It swaps in the relevant devTools contents for a given TabContents or removes
// the view, if there's no devTools contents to show.
@interface DevToolsController : NSObject<NSSplitViewDelegate> {
@private
@@ -27,12 +29,9 @@ class TabContents;
scoped_nsobject<NSSplitView> splitView_;
BOOL dockToRight_;
-
- // Manages currently displayed devTools contents.
- scoped_nsobject<TabContentsController> contentsController_;
}
-- (id)initWithDelegate:(id<TabContentsControllerDelegate>)delegate;
+- (id)init;
// This controller's view.
- (NSView*)view;
@@ -50,11 +49,6 @@ class TabContents;
// Specifies whether devtools should dock to right.
- (void)setDockToRight:(BOOL)dock_to_right
withProfile:(Profile*)profile;
-
-// Call when the devTools view is properly sized and the render widget host view
-// should be put into the view hierarchy.
-- (void)ensureContentsVisible;
-
@end
#endif // CHROME_BROWSER_UI_COCOA_DEV_TOOLS_CONTROLLER_H_
« no previous file with comments | « chrome/browser/ui/cocoa/browser_window_controller.mm ('k') | chrome/browser/ui/cocoa/dev_tools_controller.mm » ('j') | no next file with comments »
@@ -10,16 +10,18 @@
// A class that handles updates of the devTools view within a browser window.
-// It swaps in the relevant devTools contents for a given TabContents or removes
+// It swaps in the relevant devTools contents for a given WebContents or removes
// the view, if there's no devTools contents to show.

Powered by Google App Engine
This is Rietveld 408576698